import { LocationQueryValue } from "vue-router";
interface HttpResponse<T = unknown> {
    data: T;
    headers: Record<string, unknown>;
}
export declare class PaginatedList<T> {
    data: T[];
    totalCount: number;
    offset: number;
    limit: number;
    readonly loading: boolean;
    constructor(loading?: boolean);
    /**
     * this 뒤에 list 의 항목들을 추가한다.
     *
     * - totalCount 가 새로운 list 의 totalCount 로 변경된다.
     * - limit 이 list.length 만큼 증가한다.
     *
     * @return this 객체
     */
    append(list: PaginatedList<T>): PaginatedList<T>;
    /**
     * this 앞에 list 의 항목들을 추가한다.
     *
     * - totalCount 가 새로운 list 의 totalCount 로 변경된다.
     * - offset 이 list.length 만큼 줄어든다.
     * - limit 이 list.length 만큼 증가한다.
     *
     * @return this 객체
     */
    prepend(list: PaginatedList<T>): PaginatedList<T>;
    /**
     * PaginatedList 의 모든 데이터를 삭제하고,
     * totalCount=0, offset=0, limit=0 으로 변경한다.
     */
    clear(): void;
    /**
     * PaginatedList 가 로딩중인지 확인한다.
     * `PaginatedList.loading()` 으로 생성한 것만이 로딩중인 PaginatedList 이다.
     */
    isLoading(): boolean;
    /**
     * @return 로딩된 데이터가 비어있으면 true
     */
    isEmpty(): boolean;
    static of<T>(data?: T[], totalCount?: number | undefined, offset?: number, limit?: number | undefined): PaginatedList<T>;
    /**
     * `AxiosResponse` 등의 http response 로부터 `PaginatedList` 를 생성한다.
     * @param response
     * @param converter
     */
    static fromAxiosResponse<T, D = T>(response: HttpResponse<T[]>, converter?: (data: T) => D): PaginatedList<D>;
    /**
     * Axios Header 와 response data 로부터 `PaginatedList` 를 생성한다.
     * @param headers
     * @param data
     * @param converter
     */
    static fromAxiosHeader<T, D = T>(headers: Record<string, unknown>, data: T[], converter?: (data: T) => D): PaginatedList<D>;
    /**
     * 로딩중을 나타내는 PaginatedList 를 생성한다.
     */
    static loading<T>(): PaginatedList<T>;
}
/**
 * PaginatedList 를 가져오기 위한 요청 정보
 */
export declare type PaginatedListRequest = {
    offset: number;
    limit: number;
};
/**
 * PaginatedList 로드 정보
 */
export declare type PaginatedListLoadInfo = {
    totalCount: number;
    offset: number;
    limit: number;
};
/**
 * 목록 검색 조건
 */
export declare class ListCondition {
    readonly values: string[];
    readonly defaultValue: string;
    constructor(values: string[], defaultValue?: string);
    toSelectItems(captionProvider?: (value?: string) => string | undefined): {
        value: string;
        caption: string;
    }[];
    fromRouterQuery(queryValue: LocationQueryValue | LocationQueryValue[]): string;
}
export {};
